@@ -14,7 +14,7 @@ mod url_parts;
 mod version_hash;
 mod xorurl_media_types;
 
-use crate::client::{BlobAddress, SpotAddress};
+use crate::client::BytesAddress;
 use crate::types::register;
 pub use errors::{Error, Result};
 use multibase::{decode as base_decode, encode as base_encode, Base};
@@ -158,11 +158,9 @@ pub enum DataType {
     #[allow(missing_docs)]
     SafeKey = 0x00,
     #[allow(missing_docs)]
-    Blob = 0x01,
+    Bytes = 0x01,
     #[allow(missing_docs)]
     Register = 0x02,
-    #[allow(missing_docs)]
-    Spot = 0x03,
 }
 
 impl std::fmt::Display for DataType {
@@ -512,9 +510,8 @@ impl Url {
 
         let data_type = match xorurl_bytes[4] {
             0 => DataType::SafeKey,
-            1 => DataType::Blob,
+            1 => DataType::Bytes,
             2 => DataType::Register,
-            3 => DataType::Spot,
             other => {
                 return Err(Error::InvalidXorUrl(format!(
                     "Invalid data type encoded in the XOR-URL string: {}",
@@ -1033,9 +1030,9 @@ impl Url {
         )
     }
 
-    /// A non-member Blob encoder function for convenience
-    pub fn encode_blob(
-        address: BlobAddress,
+    /// A non-member bytes encoder function for convenience
+    pub fn encode_bytes(
+        address: BytesAddress,
         content_type: ContentType,
         base: XorUrlBase,
     ) -> Result<String> {
@@ -1044,29 +1041,7 @@ impl Url {
             None,
             0,
             address.scope(),
-            DataType::Blob,
-            content_type,
-            None,
-            None,
-            None,
-            None,
-            None,
-            base,
-        )
-    }
-
-    /// A non-member Spot encoder function for convenience
-    pub fn encode_spot(
-        address: SpotAddress,
-        content_type: ContentType,
-        base: XorUrlBase,
-    ) -> Result<String> {
-        Url::encode(
-            *address.name(),
-            None,
-            0,
-            address.scope(),
-            DataType::Spot,
+            DataType::Bytes,
             content_type,
             None,
             None,
@@ -1262,6 +1237,7 @@ impl fmt::Display for Url {
 #[cfg(test)]
 mod tests {
     use super::*;
+    use crate::client::BlobAddress;
     use eyre::{bail, eyre, Result};
 
     macro_rules! verify_expected_result {
@@ -1370,7 +1346,7 @@ mod tests {
             None,
             0xa632_3c4d_4a32,
             Scope::Public,
-            DataType::Blob,
+            DataType::Bytes,
             ContentType::Raw,
             None,
             None,
@@ -1388,8 +1364,8 @@ mod tests {
     #[test]
     fn test_url_base32z_encoding() -> Result<()> {
         let xor_name = XorName(*b"12345678901234567890123456789012");
-        let xorurl = Url::encode_blob(
-            BlobAddress::Public(xor_name),
+        let xorurl = Url::encode_bytes(
+            BytesAddress::Blob(BlobAddress::Public(xor_name)),
             ContentType::Raw,
             XorUrlBase::Base32z,
         )?;
@@ -1426,8 +1402,8 @@ mod tests {
     fn test_url_default_base_encoding() -> Result<()> {
         let xor_name = XorName(*b"12345678901234567890123456789012");
         let base32z_xorurl = "safe://hyryyyyybgr3dgpbiga5uoqjogr3dgpbiga5uoqjogr3dgpbiga5uoqjogr3y";
-        let xorurl = Url::encode_blob(
-            BlobAddress::Public(xor_name),
+        let xorurl = Url::encode_bytes(
+            BytesAddress::Blob(BlobAddress::Public(xor_name)),
             ContentType::Raw,
             DEFAULT_XORURL_BASE,
         )?;
@@ -1449,7 +1425,7 @@ mod tests {
             None,
             type_tag,
             Scope::Public,
-            DataType::Blob,
+            DataType::Bytes,
             ContentType::Raw,
             Some(subdirs),
             Some(vec!["subname".to_string()]),
@@ -1465,7 +1441,7 @@ mod tests {
         assert_eq!(xor_name, url.xorname());
         assert_eq!(type_tag, url.type_tag());
         assert_eq!(Scope::Public, url.scope());
-        assert_eq!(DataType::Blob, url.data_type());
+        assert_eq!(DataType::Bytes, url.data_type());
         assert_eq!(ContentType::Raw, url.content_type());
         assert_eq!(Some(content_version), url.content_version());
         assert_eq!(query_string_v, url.query_string());
@@ -1507,7 +1483,7 @@ mod tests {
             None,
             type_tag,
             Scope::Public,
-            DataType::Blob,
+            DataType::Bytes,
             ContentType::NrsMapContainer,
             None,
             Some(vec!["sub".to_string()]),
@@ -1536,10 +1512,10 @@ mod tests {
     }
 
     #[test]
-    fn encode_blob_should_set_media_type() -> Result<()> {
+    fn encode_bytes_should_set_media_type() -> Result<()> {
         let xor_name = XorName(*b"12345678901234567890123456789012");
-        let xorurl = Url::encode_blob(
-            BlobAddress::Public(xor_name),
+        let xorurl = Url::encode_bytes(
+            BytesAddress::Blob(BlobAddress::Public(xor_name)),
             ContentType::MediaType("text/html".to_string()),
             XorUrlBase::Base32z,
         )?;
@@ -1553,47 +1529,16 @@ mod tests {
     }
 
     #[test]
-    fn encode_blob_should_set_data_type() -> Result<()> {
+    fn encode_bytes_should_set_data_type() -> Result<()> {
         let xor_name = XorName(*b"12345678901234567890123456789012");
-        let xorurl = Url::encode_blob(
-            BlobAddress::Public(xor_name),
+        let xorurl = Url::encode_bytes(
+            BytesAddress::Blob(BlobAddress::Public(xor_name)),
             ContentType::MediaType("text/html".to_string()),
             XorUrlBase::Base32z,
         )?;
 
         let url = Url::from_url(&xorurl)?;
-        assert_eq!(url.data_type(), DataType::Blob);
-        Ok(())
-    }
-
-    #[test]
-    fn encode_spot_should_set_media_type() -> Result<()> {
-        let xor_name = XorName(*b"12345678901234567890123456789012");
-        let xorurl = Url::encode_spot(
-            SpotAddress::Public(xor_name),
-            ContentType::MediaType("text/html".to_string()),
-            XorUrlBase::Base32z,
-        )?;
-
-        let url = Url::from_url(&xorurl)?;
-        assert_eq!(
-            ContentType::MediaType("text/html".to_string()),
-            url.content_type()
-        );
-        Ok(())
-    }
-
-    #[test]
-    fn encode_spot_should_set_data_type() -> Result<()> {
-        let xor_name = XorName(*b"12345678901234567890123456789012");
-        let xorurl = Url::encode_spot(
-            SpotAddress::Public(xor_name),
-            ContentType::MediaType("text/html".to_string()),
-            XorUrlBase::Base32z,
-        )?;
-
-        let url = Url::from_url(&xorurl)?;
-        assert_eq!(url.data_type(), DataType::Spot);
+        assert_eq!(url.data_type(), DataType::Bytes);
         Ok(())
     }
 
@@ -1617,8 +1562,8 @@ mod tests {
     #[test]
     fn test_url_too_short() -> Result<()> {
         let xor_name = XorName(*b"12345678901234567890123456789012");
-        let xorurl = Url::encode_blob(
-            BlobAddress::Public(xor_name),
+        let xorurl = Url::encode_bytes(
+            BytesAddress::Blob(BlobAddress::Public(xor_name)),
             ContentType::MediaType("text/html".to_string()),
             XorUrlBase::Base32z,
         )?;
